summaryrefslogtreecommitdiff
path: root/ucb/source/core/ucbstore.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'ucb/source/core/ucbstore.cxx')
-rw-r--r--ucb/source/core/ucbstore.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/ucb/source/core/ucbstore.cxx b/ucb/source/core/ucbstore.cxx
index 6fdffba75003..f717faf7f6eb 100644
--- a/ucb/source/core/ucbstore.cxx
+++ b/ucb/source/core/ucbstore.cxx
@@ -1704,8 +1704,8 @@ void SAL_CALL PersistentPropertySet::addProperty(
}
}
- // Property is always removeable.
- Attributes |= PropertyAttribute::REMOVEABLE;
+ // Property is always removable.
+ Attributes |= PropertyAttribute::REMOVABLE;
// Add property.
@@ -1852,7 +1852,7 @@ void SAL_CALL PersistentPropertySet::removeProperty( const OUString& Name )
if ( !xRootHierNameAccess->hasByHierarchicalName( aFullPropName ) )
throw UnknownPropertyException();
- // Property removeable?
+ // Property removable?
try
{
OUString aFullAttrName = aFullPropName;
@@ -1862,9 +1862,9 @@ void SAL_CALL PersistentPropertySet::removeProperty( const OUString& Name )
if ( xRootHierNameAccess->getByHierarchicalName( aFullAttrName )
>>= nAttribs )
{
- if ( !( nAttribs & PropertyAttribute::REMOVEABLE ) )
+ if ( !( nAttribs & PropertyAttribute::REMOVABLE ) )
{
- // Not removeable!
+ // Not removable!
throw NotRemoveableException();
}
}